@@ -1,25 +1,26 @@
-# Copyright (c) 2015-2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2017 Derek Gustafson <degustaf@gmail.com>
-# Copyright (c) 2019, 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 """Checker for anything related to the async protocol (PEP 492)."""
 
+from __future__ import annotations
+
 import sys
+from typing import TYPE_CHECKING
 
 import astroid
-from astroid import bases, exceptions
+from astroid import nodes
 
-from pylint import checkers, interfaces, utils
+from pylint import checkers
 from pylint.checkers import utils as checker_utils
 from pylint.checkers.utils import decorated_with
 
+if TYPE_CHECKING:
+    from pylint.lint import PyLinter
+
 
 class AsyncChecker(checkers.BaseChecker):
-    __implements__ = interfaces.IAstroidChecker
     name = "async"
     msgs = {
         "E1700": (
@@ -38,33 +39,31 @@ class AsyncChecker(checkers.BaseChecker):
         ),
     }
 
-    def open(self):
-        self._ignore_mixin_members = utils.get_global_option(
-            self, "ignore-mixin-members"
-        )
+    def open(self) -> None:
+        self._mixin_class_rgx = self.linter.config.mixin_class_rgx
         self._async_generators = ["contextlib.asynccontextmanager"]
 
-    @checker_utils.check_messages("yield-inside-async-function")
-    def visit_asyncfunctiondef(self, node):
-        for child in node.nodes_of_class(astroid.Yield):
+    @checker_utils.only_required_for_messages("yield-inside-async-function")
+    def visit_asyncfunctiondef(self, node: nodes.AsyncFunctionDef) -> None:
+        for child in node.nodes_of_class(nodes.Yield):
             if child.scope() is node and (
-                sys.version_info[:2] == (3, 5) or isinstance(child, astroid.YieldFrom)
+                sys.version_info[:2] == (3, 5) or isinstance(child, nodes.YieldFrom)
             ):
                 self.add_message("yield-inside-async-function", node=child)
 
-    @checker_utils.check_messages("not-async-context-manager")
-    def visit_asyncwith(self, node):
+    @checker_utils.only_required_for_messages("not-async-context-manager")
+    def visit_asyncwith(self, node: nodes.AsyncWith) -> None:
         for ctx_mgr, _ in node.items:
             inferred = checker_utils.safe_infer(ctx_mgr)
             if inferred is None or inferred is astroid.Uninferable:
                 continue
 
-            if isinstance(inferred, astroid.AsyncFunctionDef):
+            if isinstance(inferred, nodes.AsyncFunctionDef):
                 # Check if we are dealing with a function decorated
                 # with contextlib.asynccontextmanager.
                 if decorated_with(inferred, self._async_generators):
                     continue
-            elif isinstance(inferred, bases.AsyncGenerator):
+            elif isinstance(inferred, astroid.bases.AsyncGenerator):
                 # Check if we are dealing with a function decorated
                 # with contextlib.asynccontextmanager.
                 if decorated_with(inferred.parent, self._async_generators):
@@ -73,16 +72,19 @@ class AsyncChecker(checkers.BaseChecker):
                 try:
                     inferred.getattr("__aenter__")
                     inferred.getattr("__aexit__")
-                except exceptions.NotFoundError:
+                except astroid.exceptions.NotFoundError:
                     if isinstance(inferred, astroid.Instance):
                         # If we do not know the bases of this class,
                         # just skip it.
                         if not checker_utils.has_known_bases(inferred):
                             continue
-                        # Just ignore mixin classes.
-                        if self._ignore_mixin_members:
-                            if inferred.name[-5:].lower() == "mixin":
-                                continue
+                        # Ignore mixin classes if they match the rgx option.
+                        if (
+                            "not-async-context-manager"
+                            in self.linter.config.ignored_checks_for_mixins
+                            and self._mixin_class_rgx.match(inferred.name)
+                        ):
+                            continue
                 else:
                     continue
             self.add_message(
@@ -90,6 +92,5 @@ class AsyncChecker(checkers.BaseChecker):
             )
 
 
-def register(linter):
-    """required method to auto register this checker"""
+def register(linter: PyLinter) -> None:
     linter.register_checker(AsyncChecker(linter))
