@@ -1,9 +1,13 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 """Checker mixin for deprecated functionality."""
+
+from __future__ import annotations
+
+from collections.abc import Container, Iterable
 from itertools import chain
-from typing import Any, Container, Iterable, Tuple, Union
 
 import astroid
 from astroid import nodes
@@ -11,6 +15,7 @@ from astroid import nodes
 from pylint.checkers import utils
 from pylint.checkers.base_checker import BaseChecker
 from pylint.checkers.utils import get_import_name, infer_all, safe_infer
+from pylint.typing import MessageDefinitionTuple
 
 ACCEPTABLE_NODES = (
     astroid.BoundMethod,
@@ -22,38 +27,56 @@ ACCEPTABLE_NODES = (
 
 class DeprecatedMixin(BaseChecker):
     """A mixin implementing logic for checking deprecated symbols.
+
     A class implementing mixin must define "deprecated-method" Message.
     """
 
-    msgs: Any = {
-        "W1505": (
-            "Using deprecated method %s()",
-            "deprecated-method",
-            "The method is marked as deprecated and will be removed in the future.",
-        ),
-        "W1511": (
-            "Using deprecated argument %s of method %s()",
-            "deprecated-argument",
-            "The argument is marked as deprecated and will be removed in the future.",
-        ),
-        "W0402": (
-            "Uses of a deprecated module %r",
+    DEPRECATED_MODULE_MESSAGE: dict[str, MessageDefinitionTuple] = {
+        "W4901": (
+            "Deprecated module %r",
             "deprecated-module",
             "A module marked as deprecated is imported.",
-        ),
-        "W1512": (
-            "Using deprecated class %s of module %s",
-            "deprecated-class",
-            "The class is marked as deprecated and will be removed in the future.",
-        ),
-        "W1513": (
-            "Using deprecated decorator %s()",
-            "deprecated-decorator",
-            "The decorator is marked as deprecated and will be removed in the future.",
+            {"old_names": [("W0402", "old-deprecated-module")], "shared": True},
         ),
     }
 
-    @utils.check_messages(
+    DEPRECATED_METHOD_MESSAGE: dict[str, MessageDefinitionTuple] = {
+        "W4902": (
+            "Using deprecated method %s()",
+            "deprecated-method",
+            "The method is marked as deprecated and will be removed in the future.",
+            {"old_names": [("W1505", "old-deprecated-method")], "shared": True},
+        ),
+    }
+
+    DEPRECATED_ARGUMENT_MESSAGE: dict[str, MessageDefinitionTuple] = {
+        "W4903": (
+            "Using deprecated argument %s of method %s()",
+            "deprecated-argument",
+            "The argument is marked as deprecated and will be removed in the future.",
+            {"old_names": [("W1511", "old-deprecated-argument")], "shared": True},
+        ),
+    }
+
+    DEPRECATED_CLASS_MESSAGE: dict[str, MessageDefinitionTuple] = {
+        "W4904": (
+            "Using deprecated class %s of module %s",
+            "deprecated-class",
+            "The class is marked as deprecated and will be removed in the future.",
+            {"old_names": [("W1512", "old-deprecated-class")], "shared": True},
+        ),
+    }
+
+    DEPRECATED_DECORATOR_MESSAGE: dict[str, MessageDefinitionTuple] = {
+        "W4905": (
+            "Using deprecated decorator %s()",
+            "deprecated-decorator",
+            "The decorator is marked as deprecated and will be removed in the future.",
+            {"old_names": [("W1513", "old-deprecated-decorator")], "shared": True},
+        ),
+    }
+
+    @utils.only_required_for_messages(
         "deprecated-method",
         "deprecated-argument",
         "deprecated-class",
@@ -65,12 +88,12 @@ class DeprecatedMixin(BaseChecker):
             # Calling entry point for deprecation check logic.
             self.check_deprecated_method(node, inferred)
 
-    @utils.check_messages(
+    @utils.only_required_for_messages(
         "deprecated-module",
         "deprecated-class",
     )
     def visit_import(self, node: nodes.Import) -> None:
-        """triggered when an import statement is seen"""
+        """Triggered when an import statement is seen."""
         for name in (name for name, _ in node.names):
             self.check_deprecated_module(node, name)
             if "." in name:
@@ -78,18 +101,17 @@ class DeprecatedMixin(BaseChecker):
                 mod_name, class_name = name.split(".", 1)
                 self.check_deprecated_class(node, mod_name, (class_name,))
 
-    def deprecated_decorators(self) -> Iterable:
+    def deprecated_decorators(self) -> Iterable[str]:
         """Callback returning the deprecated decorators.
 
         Returns:
             collections.abc.Container of deprecated decorator names.
         """
-        # pylint: disable=no-self-use
         return ()
 
-    @utils.check_messages("deprecated-decorator")
+    @utils.only_required_for_messages("deprecated-decorator")
     def visit_decorators(self, node: nodes.Decorators) -> None:
-        """Triggered when a decorator statement is seen"""
+        """Triggered when a decorator statement is seen."""
         children = list(node.get_children())
         if not children:
             return
@@ -101,12 +123,12 @@ class DeprecatedMixin(BaseChecker):
         if qname in self.deprecated_decorators():
             self.add_message("deprecated-decorator", node=node, args=qname)
 
-    @utils.check_messages(
+    @utils.only_required_for_messages(
         "deprecated-module",
         "deprecated-class",
     )
     def visit_importfrom(self, node: nodes.ImportFrom) -> None:
-        """triggered when a from statement is seen"""
+        """Triggered when a from statement is seen."""
         basename = node.modname
         basename = get_import_name(node, basename)
         self.check_deprecated_module(node, basename)
@@ -119,12 +141,9 @@ class DeprecatedMixin(BaseChecker):
         Returns:
             collections.abc.Container of deprecated function/method names.
         """
-        # pylint: disable=no-self-use
         return ()
 
-    def deprecated_arguments(
-        self, method: str
-    ) -> Iterable[Tuple[Union[int, None], str]]:
+    def deprecated_arguments(self, method: str) -> Iterable[tuple[int | None, str]]:
         """Callback returning the deprecated arguments of method/function.
 
         Args:
@@ -147,20 +166,18 @@ class DeprecatedMixin(BaseChecker):
             .. code-block:: python
                 ((1, 'arg2'), (3, 'arg4'))
         """
-        # pylint: disable=no-self-use
         # pylint: disable=unused-argument
         return ()
 
-    def deprecated_modules(self) -> Iterable:
+    def deprecated_modules(self) -> Iterable[str]:
         """Callback returning the deprecated modules.
 
         Returns:
             collections.abc.Container of deprecated module names.
         """
-        # pylint: disable=no-self-use
         return ()
 
-    def deprecated_classes(self, module: str) -> Iterable:
+    def deprecated_classes(self, module: str) -> Iterable[str]:
         """Callback returning the deprecated classes of module.
 
         Args:
@@ -169,19 +186,19 @@ class DeprecatedMixin(BaseChecker):
         Returns:
             collections.abc.Container of deprecated class names.
         """
-        # pylint: disable=no-self-use
         # pylint: disable=unused-argument
         return ()
 
-    def check_deprecated_module(self, node, mod_path):
-        """Checks if the module is deprecated"""
+    def check_deprecated_module(self, node: nodes.Import, mod_path: str | None) -> None:
+        """Checks if the module is deprecated."""
         for mod_name in self.deprecated_modules():
-            if mod_path == mod_name or mod_path.startswith(mod_name + "."):
+            if mod_path == mod_name or mod_path and mod_path.startswith(mod_name + "."):
                 self.add_message("deprecated-module", node=node, args=mod_path)
 
-    def check_deprecated_method(self, node, inferred):
-        """Executes the checker for the given node. This method should
-        be called from the checker implementing this mixin.
+    def check_deprecated_method(self, node: nodes.Call, inferred: nodes.NodeNG) -> None:
+        """Executes the checker for the given node.
+
+        This method should be called from the checker implementing this mixin.
         """
 
         # Reject nodes which aren't of interest to us.
@@ -196,16 +213,7 @@ class DeprecatedMixin(BaseChecker):
             # Not interested in other nodes.
             return
 
-        if hasattr(inferred.parent, "qname") and inferred.parent.qname():
-            # Handling the situation when deprecated function is
-            # alias to existing function.
-            qnames = {
-                inferred.qname(),
-                f"{inferred.parent.qname()}.{func_name}",
-                func_name,
-            }
-        else:
-            qnames = {inferred.qname(), func_name}
+        qnames = {inferred.qname(), func_name}
         if any(name in self.deprecated_methods() for name in qnames):
             self.add_message("deprecated-method", node=node, args=(func_name,))
             return
@@ -224,8 +232,10 @@ class DeprecatedMixin(BaseChecker):
                     "deprecated-argument", node=node, args=(arg_name, func_name)
                 )
 
-    def check_deprecated_class(self, node, mod_name, class_names):
-        """Checks if the class is deprecated"""
+    def check_deprecated_class(
+        self, node: nodes.NodeNG, mod_name: str, class_names: Iterable[str]
+    ) -> None:
+        """Checks if the class is deprecated."""
 
         for class_name in class_names:
             if class_name in self.deprecated_classes(mod_name):
@@ -233,8 +243,8 @@ class DeprecatedMixin(BaseChecker):
                     "deprecated-class", node=node, args=(class_name, mod_name)
                 )
 
-    def check_deprecated_class_in_call(self, node):
-        """Checks if call the deprecated class"""
+    def check_deprecated_class_in_call(self, node: nodes.Call) -> None:
+        """Checks if call the deprecated class."""
 
         if isinstance(node.func, nodes.Attribute) and isinstance(
             node.func.expr, nodes.Name
