@@ -1,32 +1,8 @@
-# Copyright (c) 2009-2011, 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2012 FELD Boris <lothiraldan@gmail.com>
-# Copyright (c) 2013-2014 Google, Inc.
-# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2014 buck <buck.2019@gmail.com>
-# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
-# Copyright (c) 2015 Harut <yes@harutune.name>
-# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
-# Copyright (c) 2016 Petr Pulc <petrpulc@gmail.com>
-# Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
-# Copyright (c) 2017 Krzysztof Czapla <k.czapla68@gmail.com>
-# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2017 James M. Allen <james.m.allen@gmail.com>
-# Copyright (c) 2017 vinnyrose <vinnyrose@users.noreply.github.com>
-# Copyright (c) 2018, 2020 Bryce Guinta <bryce.guinta@protonmail.com>
-# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
-# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2021 Andreas Finkler <andi.finkler@gmail.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
-"""Check format checker helper functions"""
+"""Check format checker helper functions."""
 
 import os
 import tempfile
@@ -35,6 +11,7 @@ import tokenize
 import astroid
 
 from pylint import lint, reporters
+from pylint.checkers.base.basic_checker import BasicChecker
 from pylint.checkers.format import FormatChecker
 from pylint.testutils import CheckerTestCase, MessageTest, _tokenize_str
 
@@ -109,7 +86,8 @@ class TestSuperfluousParentheses(CheckerTestCase):
 
     def testNoSuperfluousParensWalrusOperatorIf(self) -> None:
         """Parenthesis change the meaning of assignment in the walrus operator
-        and so are not always superfluous:"""
+        and so are not always superfluous:
+        """
         cases = [
             ("if (odd := is_odd(i))\n"),
             ("not (foo := 5)\n"),
@@ -119,7 +97,7 @@ class TestSuperfluousParentheses(CheckerTestCase):
                 self.checker.process_tokens(_tokenize_str(code))
 
     def testPositiveSuperfluousParensWalrusOperatorIf(self) -> None:
-        """Test positive superfluous parens cases with the walrus operator"""
+        """Test positive superfluous parens cases with the walrus operator."""
         cases = [
             (
                 MessageTest("superfluous-parens", line=1, args="if"),
@@ -161,7 +139,7 @@ class TestCheckSpace(CheckerTestCase):
     CHECKER_CLASS = FormatChecker
 
     def test_encoding_token(self) -> None:
-        """Make sure the encoding token doesn't change the checker's behavior
+        """Make sure the encoding token doesn't change the checker's behavior.
 
         _tokenize_str doesn't produce an encoding token, but
         reading a file does
@@ -177,25 +155,22 @@ class TestCheckSpace(CheckerTestCase):
 
 
 def test_disable_global_option_end_of_line() -> None:
-    """
-    Test for issue with disabling tokenizer messages
+    """Test for issue with disabling tokenizer messages
     that extend beyond the scope of the ast tokens
     """
     file_ = tempfile.NamedTemporaryFile("w", delete=False)
     with file_:
         file_.write(
             """
-mylist = [
-    None
-        ]
+1
     """
         )
     try:
         linter = lint.PyLinter()
-        checker = FormatChecker(linter)
+        checker = BasicChecker(linter)
         linter.register_checker(checker)
-        args = linter.load_command_line_configuration(
-            [file_.name, "-d", "bad-continuation"]
+        args = linter._arguments_manager._parse_command_line_configuration(
+            [file_.name, "-d", "pointless-statement"]
         )
         myreporter = reporters.CollectingReporter()
         linter.set_reporter(myreporter)
