@@ -1,4 +1,4 @@
-# pylint: disable = disallowed-name, missing-docstring, useless-return, invalid-name, no-self-use, line-too-long, useless-object-inheritance
+# pylint: disable = disallowed-name, missing-docstring, useless-return, invalid-name, line-too-long, comparison-of-constants
 def foo():
     return None
 
@@ -18,7 +18,7 @@ if foo() == goo():
     pass
 
 
-class FakeClass(object):
+class FakeClass:
     def __init__(self):
         self._fake_prop = 'fake it till you make it!!'
 
@@ -58,3 +58,14 @@ a = 666
 b = 786
 if a == b:
     pass
+
+
+def eventually_raise():
+    print()
+    raise Exception
+
+
+if a == eventually_raise:
+    # Does not emit comparison-with-callable because the
+    # function (eventually) raises
+    pass
