@@ -1,11 +1,9 @@
-# pylint: disable=missing-docstring, no-init, useless-object-inheritance
+# pylint: disable=missing-docstring
 """check for methods first arguments
 """
 
-__revision__ = 0
 
-
-class Obj(object):
+class Obj:
     # C0202, classmethod
     def __new__(something):  # [bad-classmethod-argument]
         pass
