@@ -1,4 +1,4 @@
-#pylint: disable=invalid-name,missing-docstring,redundant-u-string-prefix
+# pylint: disable=invalid-name, missing-docstring, redundant-u-string-prefix, line-too-long
 
 # Basic test with a list
 TEST_LIST1 = ['a' 'b']  # [implicit-str-concat]
@@ -10,8 +10,8 @@ TEST_LIST3 = {r'''a''', r'''b''' r'''c'''}  # [implicit-str-concat]
 # in the middle of a list
 TEST_LIST4 = ["""a""", """b""" """c""", """d"""]  # [implicit-str-concat]
 
-# The following shouldn't raise a warning because it is a function call
-print('a', 'bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb' 'ccc')
+print("Lorem ipsum " "dolor sit amet")  # [implicit-str-concat]
+print('a', 'bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb' 'ccc')  # [implicit-str-concat]
 
 # The following shouldn't raise a warning because string literals are
 # on different lines
@@ -29,3 +29,15 @@ TEST_LIST7 = ('a' 'bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb \
 
 # No warning for bytes
 TEST_LIST8 = [b'A' b'B']
+
+# There's an internal juxtaposition on the second line in a valid multiline
+# TODO #6444: raise implicit-str-concat on the second line pylint: disable=fixme
+print(
+    "Lorem ipsum dolor sit amet, consectetur adipiscing elit,"
+    " sed do eiusmod tempor " "incididunt ut labore et dolore "
+    "magna aliqua. Ut enim ad minim veniam, quis nostrud "
+    "exercitation ullamco laboris nisi ut aliquip ex ea "
+)
+
+with open("myfile.txt" "a+b", encoding="utf8") as f:  # [implicit-str-concat]
+    content = f.read()
