@@ -1,4 +1,10 @@
-from typing import Callable, Optional
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
+
+from collections.abc import Callable
 
 import pytest
 from astroid.nodes.scoped_nodes import Module
@@ -43,10 +49,26 @@ def colorized_puml_config() -> PyreverseConfig:
     )
 
 
+@pytest.fixture()
+def mmd_config() -> PyreverseConfig:
+    return PyreverseConfig(
+        output_format="mmd",
+        colorized=False,
+    )
+
+
+@pytest.fixture()
+def html_config() -> PyreverseConfig:
+    return PyreverseConfig(
+        output_format="html",
+        colorized=False,
+    )
+
+
 @pytest.fixture(scope="session")
 def get_project() -> Callable:
-    def _get_project(module: str, name: Optional[str] = "No Name") -> Project:
-        """return an astroid project representation"""
+    def _get_project(module: str, name: str | None = "No Name") -> Project:
+        """Return an astroid project representation."""
 
         def _astroid_wrapper(func: Callable, modname: str) -> Module:
             return func(modname)
